@@ -1,7 +1,7 @@
 /*
  *  This file is part of gpw.
  *
- *  Copyright (C) 2013 Bruce Korb, all rights reserved.
+ *  Copyright (C) 2013-2014 Bruce Korb, all rights reserved.
  *  This is free software. It is licensed for use, modification and
  *  redistribution under the terms of the GNU General Public License,
  *  version 3 or later <http://gnu.org/licenses/gpl.html>
@@ -105,11 +105,12 @@ ck_pw_classes(char * pw, bool no_spec, char ** first_ch, char ** second_ch)
             res |= CCLASS_DIGIT;
 
         } else if (isalpha(ch)) {
-            if ((scan > pw + 3) && (*second_ch == NULL))
+            if ((scan > pw + 3) && (*second_ch == NULL)) {
                 if (*first_ch == NULL)
                     *first_ch = scan - 1;
                 else
                     *second_ch = scan - 1;
+            }
 
             res |= CCLASS_ALPHA |
                 (islower(ch) ? CCLASS_LOWER : CCLASS_UPPER);
@@ -132,11 +133,12 @@ ck_pw_classes(char * pw, bool no_spec, char ** first_ch, char ** second_ch)
             scan[-1] = (up ? 'A' : 'a') + (ch & 0x0F);
             res |= CCLASS_ALPHA | (up ? CCLASS_UPPER : CCLASS_LOWER);
 
-            if ((scan > pw + 3) && (*second_ch == NULL))
+            if ((scan > pw + 3) && (*second_ch == NULL)) {
                 if (*first_ch == NULL)
                     *first_ch = scan - 1;
                 else
                     *second_ch = scan - 1;
+            }
         }
     }
 }
